# -*- coding: utf-8 -*-
import logging

__version__ = "5.0.2"

logger = logging.getLogger('vies')

VIES_WSDL_URL = str('https://ec.europa.eu/taxation_customs/vies/checkVatService.wsdl')  # NoQA
VATIN_MAX_LENGTH = 14
